summaryrefslogtreecommitdiffstats
path: root/akregator
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:49:30 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:49:30 -0600
commita9bde819f2b421dcc44741156e75eca4bb5fb4f4 (patch)
treed087071b1e8fcf79698938efec19f8e48bab0799 /akregator
parent5c4a80ead2b1fe57dc6a8c29d0368792344cd61e (diff)
downloadtdepim-a9bde819f2b421dcc44741156e75eca4bb5fb4f4.tar.gz
tdepim-a9bde819f2b421dcc44741156e75eca4bb5fb4f4.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'akregator')
-rw-r--r--akregator/src/akregator_part.cpp16
-rw-r--r--akregator/src/akregator_view.cpp4
-rw-r--r--akregator/src/articlelistview.cpp4
-rw-r--r--akregator/src/articleviewer.cpp6
-rw-r--r--akregator/src/feed.cpp4
-rw-r--r--akregator/src/feediconmanager.cpp2
-rw-r--r--akregator/src/feeditem.cpp4
-rw-r--r--akregator/src/folderitem.cpp2
-rw-r--r--akregator/src/librss/loader.cpp14
-rw-r--r--akregator/src/librss/loader.h6
-rw-r--r--akregator/src/mainwindow.cpp4
-rw-r--r--akregator/src/mk4storage/feedstoragemk4impl.cpp2
-rw-r--r--akregator/src/mk4storage/storagemk4impl.cpp2
-rw-r--r--akregator/src/mk4storage/storagemk4impl.h2
-rw-r--r--akregator/src/notificationmanager.cpp2
-rw-r--r--akregator/src/pageviewer.cpp6
-rw-r--r--akregator/src/searchbar.cpp2
-rw-r--r--akregator/src/tagnodeitem.cpp4
-rw-r--r--akregator/src/trayicon.cpp2
-rw-r--r--akregator/src/viewer.cpp4
20 files changed, 46 insertions, 46 deletions
diff --git a/akregator/src/akregator_part.cpp b/akregator/src/akregator_part.cpp
index 9d9c574eb..cab78590a 100644
--- a/akregator/src/akregator_part.cpp
+++ b/akregator/src/akregator_part.cpp
@@ -133,9 +133,9 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
// start knotifyclient if not already started. makes it work for people who doesn't use full kde, according to kmail devels
KNotifyClient::startDaemon();
- m_standardFeedList = KGlobal::dirs()->saveLocation("data", "akregator/data") + "/feeds.opml";
+ m_standardFeedList = TDEGlobal::dirs()->saveLocation("data", "akregator/data") + "/feeds.opml";
- m_tagSetPath = KGlobal::dirs()->saveLocation("data", "akregator/data") + "/tagset.xml";
+ m_tagSetPath = TDEGlobal::dirs()->saveLocation("data", "akregator/data") + "/tagset.xml";
Backend::StorageFactoryDummyImpl* dummyFactory = new Backend::StorageFactoryDummyImpl();
Backend::StorageFactoryRegistry::self()->registerFactory(dummyFactory, dummyFactory->key());
@@ -832,10 +832,10 @@ void Part::initFonts()
TQStringList fonts = Settings::fonts();
if (fonts.isEmpty())
{
- fonts.append(KGlobalSettings::generalFont().family());
- fonts.append(KGlobalSettings::fixedFont().family());
- fonts.append(KGlobalSettings::generalFont().family());
- fonts.append(KGlobalSettings::generalFont().family());
+ fonts.append(TDEGlobalSettings::generalFont().family());
+ fonts.append(TDEGlobalSettings::fixedFont().family());
+ fonts.append(TDEGlobalSettings::generalFont().family());
+ fonts.append(TDEGlobalSettings::generalFont().family());
fonts.append("0");
}
Settings::setFonts(fonts);
@@ -860,7 +860,7 @@ void Part::initFonts()
if (konq.hasKey("MinimumFontSize"))
minfs = konq.readNumEntry("MinimumFontSize");
else
- minfs = KGlobalSettings::generalFont().pointSize();
+ minfs = TDEGlobalSettings::generalFont().pointSize();
kdDebug() << "Part::initFonts(): set MinimumFontSize to " << minfs << endl;
Settings::setMinimumFontSize(minfs);
}
@@ -871,7 +871,7 @@ void Part::initFonts()
if (konq.hasKey("MediumFontSize"))
medfs = konq.readNumEntry("MediumFontSize");
else
- medfs = KGlobalSettings::generalFont().pointSize();
+ medfs = TDEGlobalSettings::generalFont().pointSize();
kdDebug() << "Part::initFonts(): set MediumFontSize to " << medfs << endl;
Settings::setMediumFontSize(medfs);
}
diff --git a/akregator/src/akregator_view.cpp b/akregator/src/akregator_view.cpp
index 7a14c2891..605ae738b 100644
--- a/akregator/src/akregator_view.cpp
+++ b/akregator/src/akregator_view.cpp
@@ -247,7 +247,7 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
m_listTabWidget->setViewMode(ListTabWidget::single);
m_feedListView = new NodeListView( this, "feedtree" );
- m_listTabWidget->addView(m_feedListView, i18n("Feeds"), KGlobal::iconLoader()->loadIcon("folder", KIcon::Small));
+ m_listTabWidget->addView(m_feedListView, i18n("Feeds"), TDEGlobal::iconLoader()->loadIcon("folder", KIcon::Small));
connect(m_feedListView, TQT_SIGNAL(signalContextMenu(KListView*, TreeNode*, const TQPoint&)), this, TQT_SLOT(slotFeedTreeContextMenu(KListView*, TreeNode*, const TQPoint&)));
@@ -256,7 +256,7 @@ View::View( Part *part, TQWidget *parent, ActionManagerImpl* actionManager, cons
TreeNode*, Folder*)));
m_tagNodeListView = new NodeListView(this);
- m_listTabWidget->addView(m_tagNodeListView, i18n("Tags"), KGlobal::iconLoader()->loadIcon("rss_tag", KIcon::Small));
+ m_listTabWidget->addView(m_tagNodeListView, i18n("Tags"), TDEGlobal::iconLoader()->loadIcon("rss_tag", KIcon::Small));
connect(m_tagNodeListView, TQT_SIGNAL(signalContextMenu(KListView*, TreeNode*, const TQPoint&)), this, TQT_SLOT(slotFeedTreeContextMenu(KListView*, TreeNode*, const TQPoint&)));
diff --git a/akregator/src/articlelistview.cpp b/akregator/src/articlelistview.cpp
index 3449ee9cf..aad2dd05a 100644
--- a/akregator/src/articlelistview.cpp
+++ b/akregator/src/articlelistview.cpp
@@ -156,7 +156,7 @@ class ArticleListView::ArticleItem : public KListViewItem
// FIXME: Remove resolveEntities for KDE 4.0, it's now done in the parser
ArticleListView::ArticleItem::ArticleItem( TQListView *parent, const Article& a)
- : KListViewItem( parent, KCharsets::resolveEntities(a.title()), a.feed()->title(), KGlobal::locale()->formatDateTime(a.pubDate(), true, false) ), m_article(a), m_pubDate(a.pubDate().toTime_t())
+ : KListViewItem( parent, KCharsets::resolveEntities(a.title()), a.feed()->title(), TDEGlobal::locale()->formatDateTime(a.pubDate(), true, false) ), m_article(a), m_pubDate(a.pubDate().toTime_t())
{
if (a.keep())
setPixmap(0, keepFlag());
@@ -197,7 +197,7 @@ void ArticleListView::ArticleItem::updateItem(const Article& article)
setPixmap(0, m_article.keep() ? keepFlag() : TQPixmap());
setText(0, KCharsets::resolveEntities(m_article.title()));
setText(1, m_article.feed()->title());
- setText(2, KGlobal::locale()->formatDateTime(m_article.pubDate(), true, false));
+ setText(2, TDEGlobal::locale()->formatDateTime(m_article.pubDate(), true, false));
}
int ArticleListView::ArticleItem::compare(TQListViewItem *i, int col, bool ascending) const {
diff --git a/akregator/src/articleviewer.cpp b/akregator/src/articleviewer.cpp
index f5fd8a5ee..b9dee41a2 100644
--- a/akregator/src/articleviewer.cpp
+++ b/akregator/src/articleviewer.cpp
@@ -177,7 +177,7 @@ ArticleViewer::ArticleViewer(TQWidget *parent, const char *name)
connect(kapp, TQT_SIGNAL(kdisplayPaletteChanged()), this, TQT_SLOT(slotPaletteOrFontChanged()) );
connect(kapp, TQT_SIGNAL(kdisplayFontChanged()), this, TQT_SLOT(slotPaletteOrFontChanged()) );
- m_imageDir.setPath(KGlobal::dirs()->saveLocation("cache", "akregator/Media/"));
+ m_imageDir.setPath(TDEGlobal::dirs()->saveLocation("cache", "akregator/Media/"));
m_htmlFooter = "</body></html>";
}
@@ -420,7 +420,7 @@ TQString ArticleViewer::formatArticleNormalMode(Feed* feed, const Article& artic
text += TQString("<span class=\"header\" dir=\"%1\">").arg(directionOf(i18n("Date")));
text += TQString ("%1:").arg(i18n("Date"));
text += "</span><span class=\"headertext\">";
- text += KGlobal::locale()->formatDateTime(article.pubDate(), false, false)+"</span>\n"; // TODO: might need RTL?
+ text += TDEGlobal::locale()->formatDateTime(article.pubDate(), false, false)+"</span>\n"; // TODO: might need RTL?
}
TQString author = article.author();
if (!author.isEmpty())
@@ -515,7 +515,7 @@ TQString ArticleViewer::formatArticleCombinedMode(Feed* feed, const Article& art
text += TQString("<span class=\"header\" dir=\"%1\">").arg(directionOf(i18n("Date")));
text += TQString ("%1:").arg(i18n("Date"));
text += "</span><span class=\"headertext\">";
- text += KGlobal::locale()->formatDateTime(article.pubDate(), false, false)+"</span>\n"; // TODO: might need RTL?
+ text += TDEGlobal::locale()->formatDateTime(article.pubDate(), false, false)+"</span>\n"; // TODO: might need RTL?
}
TQString author = article.author();
diff --git a/akregator/src/feed.cpp b/akregator/src/feed.cpp
index cb62b53a1..a68aedbb1 100644
--- a/akregator/src/feed.cpp
+++ b/akregator/src/feed.cpp
@@ -208,7 +208,7 @@ TQValueList<Article> Feed::articles(const TQString& tag)
void Feed::loadImage()
{
- TQString imageFileName = KGlobal::dirs()->saveLocation("cache", "akregator/Media/")
+ TQString imageFileName = TDEGlobal::dirs()->saveLocation("cache", "akregator/Media/")
+ Utils::fileNameForUrl(d->xmlUrl) +
".png";
d->imagePixmap.load(imageFileName, "PNG");
@@ -589,7 +589,7 @@ void Feed::slotImageFetched(const TQPixmap& image)
if (image.isNull())
return;
d->imagePixmap=image;
- d->imagePixmap.save(KGlobal::dirs()->saveLocation("cache", "akregator/Media/")
+ d->imagePixmap.save(TDEGlobal::dirs()->saveLocation("cache", "akregator/Media/")
+ Utils::fileNameForUrl(d->xmlUrl) +
".png","PNG");
nodeModified();
diff --git a/akregator/src/feediconmanager.cpp b/akregator/src/feediconmanager.cpp
index f1e8140b7..b4d600d45 100644
--- a/akregator/src/feediconmanager.cpp
+++ b/akregator/src/feediconmanager.cpp
@@ -140,7 +140,7 @@ void FeedIconManager::slotFeedDestroyed(TreeNode* node)
void FeedIconManager::slotIconChanged(bool /*isHost*/, const TQString& hostOrURL,
const TQString& iconName)
{
- TQString iconFile = KGlobal::dirs()->findResource("cache",
+ TQString iconFile = TDEGlobal::dirs()->findResource("cache",
iconName+".png");
Feed* f;
TQPixmap p = TQPixmap(iconFile);
diff --git a/akregator/src/feeditem.cpp b/akregator/src/feeditem.cpp
index 03d0f077f..f9d1b3d1a 100644
--- a/akregator/src/feeditem.cpp
+++ b/akregator/src/feeditem.cpp
@@ -84,12 +84,12 @@ void FeedItem::nodeChanged()
TQPixmap FeedItem::errorPixmap()
{
- return KGlobal::iconLoader()->loadIcon("error", KIcon::Small);
+ return TDEGlobal::iconLoader()->loadIcon("error", KIcon::Small);
}
TQPixmap FeedItem::defaultPixmap()
{
- return KGlobal::iconLoader()->loadIcon("txt", KIcon::Small);
+ return TDEGlobal::iconLoader()->loadIcon("txt", KIcon::Small);
}
void FeedItem::initialize(Feed* node)
diff --git a/akregator/src/folderitem.cpp b/akregator/src/folderitem.cpp
index c9866c19c..af01736ba 100644
--- a/akregator/src/folderitem.cpp
+++ b/akregator/src/folderitem.cpp
@@ -56,7 +56,7 @@ FolderItem::FolderItem(KListView* parent, TreeNodeItem* after, Folder* node) : T
void FolderItem::initialize(Folder* node)
{
setOpen(node->isOpen());
- setPixmap ( 0, KGlobal::iconLoader()->loadIcon("folder", KIcon::Small) );
+ setPixmap ( 0, TDEGlobal::iconLoader()->loadIcon("folder", KIcon::Small) );
if (node)
setText(0, node->title());
}
diff --git a/akregator/src/librss/loader.cpp b/akregator/src/librss/loader.cpp
index 5fad14094..95f75e60d 100644
--- a/akregator/src/librss/loader.cpp
+++ b/akregator/src/librss/loader.cpp
@@ -207,12 +207,12 @@ void OutputRetriever::retrieveData(const KURL &url)
d->buffer->open(IO_WriteOnly);
d->process = new KShellProcess();
- connect(d->process, TQT_SIGNAL(processExited(KProcess *)),
- TQT_SLOT(slotExited(KProcess *)));
- connect(d->process, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)),
- TQT_SLOT(slotOutput(KProcess *, char *, int)));
+ connect(d->process, TQT_SIGNAL(processExited(TDEProcess *)),
+ TQT_SLOT(slotExited(TDEProcess *)));
+ connect(d->process, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
+ TQT_SLOT(slotOutput(TDEProcess *, char *, int)));
*d->process << url.path();
- d->process->start(KProcess::NotifyOnExit, KProcess::Stdout);
+ d->process->start(TDEProcess::NotifyOnExit, TDEProcess::Stdout);
}
int OutputRetriever::errorCode() const
@@ -220,12 +220,12 @@ int OutputRetriever::errorCode() const
return d->lastError;
}
-void OutputRetriever::slotOutput(KProcess *, char *data, int length)
+void OutputRetriever::slotOutput(TDEProcess *, char *data, int length)
{
d->buffer->writeBlock(data, length);
}
-void OutputRetriever::slotExited(KProcess *p)
+void OutputRetriever::slotExited(TDEProcess *p)
{
if (!p->normalExit())
d->lastError = p->exitStatus();
diff --git a/akregator/src/librss/loader.h b/akregator/src/librss/loader.h
index dab47f17e..0f463d773 100644
--- a/akregator/src/librss/loader.h
+++ b/akregator/src/librss/loader.h
@@ -21,7 +21,7 @@ namespace KIO
{
class Job;
}
-class KProcess;
+class TDEProcess;
namespace RSS
{
@@ -194,8 +194,8 @@ namespace RSS
virtual void abort() {}
private slots:
- void slotOutput(KProcess *process, char *data, int length);
- void slotExited(KProcess *process);
+ void slotOutput(TDEProcess *process, char *data, int length);
+ void slotExited(TDEProcess *process);
private:
OutputRetriever(const OutputRetriever &other);
diff --git a/akregator/src/mainwindow.cpp b/akregator/src/mainwindow.cpp
index 01b479baf..275a7a916 100644
--- a/akregator/src/mainwindow.cpp
+++ b/akregator/src/mainwindow.cpp
@@ -199,7 +199,7 @@ void MainWindow::optionsConfigureKeys()
void MainWindow::optionsConfigureToolbars()
{
- saveMainWindowSettings(KGlobal::config(), autoSaveGroup());
+ saveMainWindowSettings(TDEGlobal::config(), autoSaveGroup());
// use the standard toolbar editor
KEditToolbar dlg(factory());
@@ -212,7 +212,7 @@ void MainWindow::optionsConfigureToolbars()
void MainWindow::applyNewToolbarConfig()
{
- applyMainWindowSettings(KGlobal::config(), autoSaveGroup());
+ applyMainWindowSettings(TDEGlobal::config(), autoSaveGroup());
}
diff --git a/akregator/src/mk4storage/feedstoragemk4impl.cpp b/akregator/src/mk4storage/feedstoragemk4impl.cpp
index 3b567933b..58d5e31f9 100644
--- a/akregator/src/mk4storage/feedstoragemk4impl.cpp
+++ b/akregator/src/mk4storage/feedstoragemk4impl.cpp
@@ -148,7 +148,7 @@ FeedStorageMK4Impl::FeedStorageMK4Impl(const TQString& url, StorageMK4Impl* main
TQString t = url2;
TQString t2 = url2;
TQString filePath = main->archivePath() +"/"+ t.replace("/", "_").replace(":", "_");
- d->oldArchivePath = KGlobal::dirs()->saveLocation("data", "akregator/Archive/") + t2.replace("/", "_").replace(":", "_") + ".xml";
+ d->oldArchivePath = TDEGlobal::dirs()->saveLocation("data", "akregator/Archive/") + t2.replace("/", "_").replace(":", "_") + ".xml";
d->convert = !TQFile::exists(filePath + ".mk4") && TQFile::exists(d->oldArchivePath);
d->storage = new c4_Storage((filePath + ".mk4").local8Bit(), true);
diff --git a/akregator/src/mk4storage/storagemk4impl.cpp b/akregator/src/mk4storage/storagemk4impl.cpp
index becbd5186..1e104bd3f 100644
--- a/akregator/src/mk4storage/storagemk4impl.cpp
+++ b/akregator/src/mk4storage/storagemk4impl.cpp
@@ -90,7 +90,7 @@ StorageMK4Impl::StorageMK4Impl() : d(new StorageMK4ImplPrivate)
TQString StorageMK4Impl::defaultArchivePath()
{
- return KGlobal::dirs()->saveLocation("data", "akregator")+"Archive";
+ return TDEGlobal::dirs()->saveLocation("data", "akregator")+"Archive";
}
StorageMK4Impl::~StorageMK4Impl()
diff --git a/akregator/src/mk4storage/storagemk4impl.h b/akregator/src/mk4storage/storagemk4impl.h
index 182807a88..d6c4a59c9 100644
--- a/akregator/src/mk4storage/storagemk4impl.h
+++ b/akregator/src/mk4storage/storagemk4impl.h
@@ -46,7 +46,7 @@ class StorageMK4Impl : public Storage
virtual ~StorageMK4Impl();
- /** KGlobal::dirs()->saveLocation("data", "akregator")+"/Archive" */
+ /** TDEGlobal::dirs()->saveLocation("data", "akregator")+"/Archive" */
static TQString defaultArchivePath();
/** sets the directory where the metakit files will be stored.
diff --git a/akregator/src/notificationmanager.cpp b/akregator/src/notificationmanager.cpp
index 0ab3a4e88..60066c5f9 100644
--- a/akregator/src/notificationmanager.cpp
+++ b/akregator/src/notificationmanager.cpp
@@ -55,7 +55,7 @@ NotificationManager::~NotificationManager()
void NotificationManager::setWidget(TQWidget* widget, TDEInstance* inst)
{
m_widget = widget;
- m_instance = inst != NULL ? inst : KGlobal::instance();
+ m_instance = inst != NULL ? inst : TDEGlobal::instance();
}
void NotificationManager::slotNotifyArticle(const Article& article)
diff --git a/akregator/src/searchbar.cpp b/akregator/src/searchbar.cpp
index e40b50b2b..58f6c2f78 100644
--- a/akregator/src/searchbar.cpp
+++ b/akregator/src/searchbar.cpp
@@ -84,7 +84,7 @@ SearchBar::SearchBar(TQWidget* parent, const char* name) : TQHBox(parent, name),
statusLabel->setText( i18n("Status:") );
d->searchCombo = new KComboBox(this, "searchcombo");
- TQPixmap iconAll = KGlobal::iconLoader()->loadIcon("exec", KIcon::Small);
+ TQPixmap iconAll = TDEGlobal::iconLoader()->loadIcon("exec", KIcon::Small);
TQPixmap iconNew(locate("data", "akregator/pics/kmmsgnew.png"));
TQPixmap iconUnread(locate("data", "akregator/pics/kmmsgunseen.png"));
TQPixmap iconKeep(locate("data", "akregator/pics/kmmsgflag.png"));
diff --git a/akregator/src/tagnodeitem.cpp b/akregator/src/tagnodeitem.cpp
index 90e05ba2f..2c2e7f340 100644
--- a/akregator/src/tagnodeitem.cpp
+++ b/akregator/src/tagnodeitem.cpp
@@ -62,13 +62,13 @@ void TagNodeItem::initialize(TagNode* node)
if (node)
{
setText(0, node->title());
- setPixmap ( 0, KGlobal::iconLoader()->loadIcon(node->icon(), KIcon::Small) );
+ setPixmap ( 0, TDEGlobal::iconLoader()->loadIcon(node->icon(), KIcon::Small) );
}
}
void TagNodeItem::nodeChanged()
{
- setPixmap ( 0, KGlobal::iconLoader()->loadIcon(node()->icon(), KIcon::Small));
+ setPixmap ( 0, TDEGlobal::iconLoader()->loadIcon(node()->icon(), KIcon::Small));
TreeNodeItem::nodeChanged();
}
diff --git a/akregator/src/trayicon.cpp b/akregator/src/trayicon.cpp
index 0ba92b09a..441f1baf8 100644
--- a/akregator/src/trayicon.cpp
+++ b/akregator/src/trayicon.cpp
@@ -144,7 +144,7 @@ void TrayIcon::slotSetUnread(int unread)
int oldH = pixmap()->size().height();
TQString uStr=TQString::number( unread );
- TQFont f=KGlobalSettings::generalFont();
+ TQFont f=TDEGlobalSettings::generalFont();
f.setBold(true);
float pointSize=f.pointSizeFloat();
TQFontMetrics fm(f);
diff --git a/akregator/src/viewer.cpp b/akregator/src/viewer.cpp
index 8555d5096..153fb8aec 100644
--- a/akregator/src/viewer.cpp
+++ b/akregator/src/viewer.cpp
@@ -113,10 +113,10 @@ void Viewer::displayInExternalBrowser(const KURL &url, const TQString &mimetype)
TQString cmd = Settings::externalBrowserCustomCommand();
TQString urlStr = url.url();
cmd.replace(TQRegExp("%u"), urlStr);
- KProcess *proc = new KProcess;
+ TDEProcess *proc = new TDEProcess;
TQStringList cmdAndArgs = KShell::splitArgs(cmd);
*proc << cmdAndArgs;
- proc->start(KProcess::DontCare);
+ proc->start(TDEProcess::DontCare);
delete proc;
}
}
diff --git a/akregator/src/pageviewer.cpp b/akregator/src/pageviewer.cpp
index d7238d906..4baef48cb 100644
--- a/akregator/src/pageviewer.cpp
+++ b/akregator/src/pageviewer.cpp
@@ -99,7 +99,7 @@ PageViewer::PageViewer(TQWidget *parent, const char *name)
: Viewer(parent, name), d(new PageViewerPrivate)
{
// this hack is necessary since the part looks for []HTML Settings] in
// KGlobal::config() by default, which is wrong when running in Kontact
KHTMLSettings* s = const_cast<KHTMLSettings*> (settings());
s->init(Settings::self()->config());
@@ -260,7 +260,7 @@ bool PageViewer::openURL(const KURL& url)
TQString favicon = FeedIconManager::self()->iconLocation(url);
if (!favicon.isEmpty())
- emit setTabIcon(TQPixmap(KGlobal::dirs()->findResource("cache", favicon+".png")));
+ emit setTabIcon(TQPixmap(TDEGlobal::dirs()->findResource("cache", favicon+".png")));
else
emit setTabIcon(SmallIcon("html"));
@@ -398,7 +398,7 @@ void PageViewer::slotPaletteOrFontChanged()
obj->tqt_invoke(id, o);
// this hack is necessary since the part looks for []HTML Settings] in
// KGlobal::config() by default, which is wrong when running in Kontact
// NOTE: when running in Kontact, immediate updating doesn't work
KHTMLSettings* s = const_cast<KHTMLSettings*> (settings());
s->init(Settings::self()->config());
@@ -99,7 +99,7 @@ PageViewer::PageViewer(TQWidget *parent, const char *name)
{
// this hack is necessary since the part looks for []HTML Settings] in
- // KGlobal::config() by default, which is wrong when running in Kontact
+ // TDEGlobal::config() by default, which is wrong when running in Kontact
KHTMLSettings* s = const_cast<KHTMLSettings*> (settings());
s->init(Settings::self()->config());
@@ -398,7 +398,7 @@ void PageViewer::slotPaletteOrFontChanged()
obj->tqt_invoke(id, o);
// this hack is necessary since the part looks for []HTML Settings] in
- // KGlobal::config() by default, which is wrong when running in Kontact
+ // TDEGlobal::config() by default, which is wrong when running in Kontact
// NOTE: when running in Kontact, immediate updating doesn't work
KHTMLSettings* s = const_cast<KHTMLSettings*> (settings());